"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
// Light-weight
const node_fetch_1 = require("node-fetch");
class API {
    constructor(baseAPIURL, token) {
        this.baseAPIURL = baseAPIURL;
        this.token = token;
    }
    getPackagesMeta(packages) {
        return this.request("packages-meta", { packageNames: packages });
    }
    getNpmrcTemplate() {
        return this.request("config").then(userInfo => new Promise((resolve, reject) => {
            if (userInfo.npmrc === undefined) {
                reject();
            }
            else {
                resolve(Buffer.from(userInfo.npmrc, "base64").toString());
            }
        }));
    }
    request(endpoint, body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.baseAPIURL}${API.endpoints[endpoint].path}`;
            const request = new node_fetch_1.Request(url, {
                headers: { Authorization: `Token ${this.token}`, ["Content-Type"]: "application/json" },
                body: body !== undefined ? JSON.stringify(body) : body,
                method: API.endpoints[endpoint].method,
            });
            return node_fetch_1.default(request).then(response => response.json());
        });
    }
}
API.endpoints = {
    "packages-meta": { path: "/studio/packages/meta/get-many", method: "POST" },
    config: { path: "/studio/me", method: "GET" },
};
exports.API = API;
